#
# spec file for package votca
#
# Copyright (c) 2022-2024 SUSE LLC
# Copyright (c) 2021-2022 Christoph Junghans
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%global with_xtp 1
# libint2 used by xtp is broken on 32-bit archs
# https://github.com/evaleev/libint/issues/196
# https://github.com/votca/xtp/issues/652
%ifarch %ix86 %arm
%global with_xtp 0
%endif

Name:           votca
Version:        2024.2
Release:        1.5
%define         uversion %{version}
%define         sover 2024
Summary:        Versatile Object-oriented Toolkit for Coarse-graining Applications
License:        Apache-2.0
Group:          Productivity/Scientific/Chemistry
URL:            https://www.votca.org
Source0:        https://github.com/votca/votca/archive/v%{uversion}.tar.gz#/%{name}-%{uversion}.tar.gz

BuildRequires:  cmake >= 3.13
BuildRequires:  eigen3-devel
BuildRequires:  fdupes
BuildRequires:  fftw3-devel
BuildRequires:  gcc-c++
BuildRequires:  gnuplot
# gromacs is not available on 32-bit arm
%ifnarch %{arm}
BuildRequires:  gromacs-devel
# mpi gromacs is not available on 32-bit intel
# used for testing only
%ifnarch %ix86
BuildRequires:  gromacs-openmpi
%endif
%endif
BuildRequires:  hdf5-devel
BuildRequires:  lammps
BuildRequires:  libboost_filesystem-devel >= 1.71.0
BuildRequires:  libboost_program_options-devel >= 1.71.0
BuildRequires:  libboost_regex-devel >= 1.71.0
BuildRequires:  libboost_serialization-devel >= 1.71.0
BuildRequires:  libboost_system-devel >= 1.71.0
BuildRequires:  libboost_test-devel >= 1.71.0
BuildRequires:  libboost_timer-devel >= 1.71.0
BuildRequires:  libecpint-devel
BuildRequires:  libexpat-devel
%if %{with_xtp}
BuildRequires:  libint-devel
%endif
BuildRequires:  libxc-devel
BuildRequires:  memory-constraints
BuildRequires:  openmpi-macros-devel
BuildRequires:  pkg-config
BuildRequires:  procps
BuildRequires:  psmisc
BuildRequires:  python3-cma
# only needed for testing
BuildRequires:  python3-lxml
BuildRequires:  python3-pytest
# for hdf5
BuildRequires:  zlib-devel

Obsoletes:      votca-tools <= 2022~rc1
Provides:       votca-tools = %version-%release
Obsoletes:      votca-csg <= 2022~rc1
Provides:       votca-csg = %version-%release
Obsoletes:      votca-csg-apps <= 2022~rc1
Provides:       votca-csg-apps = %version-%release
Obsoletes:      votca-xtp <= 2022~rc1
Provides:       votca-xtp = %version-%release

%global votca_desc \
VOTCA is a software package which focuses on the analysis of molecular \
dynamics data, the development of systematic coarse-graining techniques as \
well as methods used for simulating microscopic charge (and exciton) transport \
in disordered semiconductors.

%description
%{votca_desc}

%package -n libvotca%sover
Summary:        VOTCA tools library
Group:          System/Libraries
Obsoletes:      libvotca_tools2022 <= 2022~rc1
Provides:       libvotca_tools2022 = %version-%release
Obsoletes:      libvotca_csg2022 <= 2022~rc1
Provides:       libvotca_csg2022 = %version-%release
Obsoletes:      libvotca_xtp2022 <= 2022~rc1
Provides:       libvotca_xtp2022 = %version-%release

%description -n libvotca%sover
%{votca_desc}

This package contains the librares of VOTCA package.

%package devel
Summary:        Development headers and libraries for votca
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       eigen3-devel
Requires:       fftw3-devel
Requires:       libexpat-devel
Requires:       libvotca%sover = %{version}
Obsoletes:      votca-tools-devel <= 2022~rc1
Provides:       votca-tools-devel = %version-%release
Obsoletes:      votca-csg-devel <= 2022~rc1
Provides:       votca-csg-devel = %version-%release
Obsoletes:      votca-xtp-devel <= 2022~rc1
Provides:       votca-xtp-devel = %version-%release

%description devel
%{votca_desc}

This package contains development headers and libraries for votca.

%package common
Summary:        Architecture-independent data files for VOTCA
Group:          Productivity/Scientific/Chemistry
BuildArch:      noarch
Requires:       /usr/bin/awk
Requires:       bash
Requires:       perl
Obsoletes:      votca-csg-common <= 2022~rc1
Provides:       votca-csg-common = %version-%release
Obsoletes:      votca-xtp-common <= 2022~rc1
Provides:       votca-xtp-common = %version-%release

%description common
%{votca_desc}

This package contains the architecture-independent data files for VOTCA.

%package tutorials
Summary:        Tutorial documentation for VOTCA Coarse Graining Engine
Group:          Productivity/Scientific/Chemistry
BuildArch:      noarch
Requires:       /bin/bash
Obsoletes:      votca-csg-tutorials <= 2022~rc1
Provides:       votca-csg-tutorials = %version-%release

%description tutorials
%{votca_desc}

This package contains the tutorial documentation and sample data.

%package bash
Summary:        Bash completion for votca
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
BuildArch:      noarch
Obsoletes:      votca-csg-bash <= 2022~rc1
Provides:       votca-csg-bash = %version-%release

%description bash
%{votca_desc}

This package contains the bash completion support for votca.

%prep
%autosetup -p1 -n %{name}-%{uversion}

%build
%setup_openmpi

# save some memory
%limit_build -m 2400
%{cmake} -DINSTALL_RC_FILES=OFF -DCMAKE_SKIP_RPATH=OFF -DENABLE_TESTING=ON -DENABLE_REGRESSION_TESTING=ON \
         -DINJECT_MARCH_NATIVE=OFF -DBUILD_CSGAPPS=ON \
         -DBUILD_XTP=%{with_xtp} \
         ..
%cmake_build

%install
%cmake_install
sed -i '1s@env @@' \
  %{buildroot}/%{_datadir}/votca/scripts/inverse/{iie,cma_processor,table_smooth_at_cut_off}.py \
  %{buildroot}/%{_datadir}/votca/csg-tutorials/LJ1-LJ2/imc/svd.py \
  %{buildroot}/%{_datadir}/votca/csg-tutorials/spce/ibi*/spce.py \
  %{buildroot}/%{_datadir}/votca/scripts/inverse/check_csg_xml.py
sed -i '1s@/usr/bin/env .*perl@/usr/bin/perl@' \
  %{buildroot}/%{_datadir}/votca/scripts/inverse/*.pl
sed -i '1s@/usr/bin/env .*bash@/bin/bash@' \
  %{buildroot}/%{_datadir}/votca/scripts/inverse/*.sh \
  %{buildroot}/%{_datadir}/votca/csg-tutorials/*/*/*.sh \
  %{buildroot}/%{_datadir}/votca/csg-tutorials/*/*.sh \
  %{buildroot}/%{_datadir}/votca/csg-tutorials/*/*/*/*.sh \
  %{buildroot}/%{_bindir}/csg_{call,inverse}

%if %{with_xtp}
chmod +x %{buildroot}/%{_datadir}/votca/xtp-tutorials/pyxtp/scripts/run_*.py
sed -i '1s@env @@' %{buildroot}/%{_bindir}/xtp_* \
  %{buildroot}/%{_datadir}/votca/xtp/benchmark/xtp_benchmark \
  %{buildroot}/%{_datadir}/votca/xtp-tutorials/pyxtp/scripts/run_*.py
sed -i '1s@/usr/bin/env .*bash@/bin/bash@' \
  %{buildroot}/%{_datadir}/votca/xtp-tutorials/clean_notebooks.sh
%endif

# Move bash completion file to correct location
mkdir -p %{buildroot}%{_datadir}/bash_completion.d
cp %{__builddir}/csg/scripts/csg-completion.bash %{buildroot}%{_datadir}/bash_completion.d/votca

%fdupes %{buildroot}%{_prefix}

%check
%setup_openmpi
%ctest

%files
%{_bindir}/{votca,csg,xtp}_*
%{_mandir}/man1/*
%{_mandir}/man7/*

%post -n libvotca%sover -p /sbin/ldconfig
%postun -n libvotca%sover -p /sbin/ldconfig

%files -n libvotca%sover
%doc NOTICE.rst README.rst CHANGELOG.rst
%license LICENSE
%{_libdir}/libvotca_*.so.%{sover}

%files devel
%{_includedir}/votca/
%{_libdir}/libvotca_*.so
%{_libdir}/cmake/VOTCA_*

%files tutorials
%{_datadir}/votca/{csg,xtp}-tutorials

%files common
%{_datadir}/votca
%exclude %{_datadir}/votca/{csg,xtp}-tutorials

%files bash
%dir %{_datadir}/bash_completion.d
%{_datadir}/bash_completion.d/votca

%changelog
* Sun Sep 29 2024 Christoph Junghans <junghans@votca.org>
- Update to v2024.2
  - Editorial changes for v2024.1 JOSS paper ([gh#votca/votca##1148],
    [gh#votca/votca##1153], [gh#votca/votca##1154])
  - Fix permissions on some scripts ([gh#votca/votca##1150])
  - Fix exit code on some scripts ([gh#votca/votca##1151])
  - Update CITATION.cff ([gh#votca/votca##1155])
  - Clean up CI ([gh#votca/votca##1146], [gh#votca/votca##1160],
    [gh#votca/votca##1161], [gh#votca/votca##1162])
  - supporting ORCA6 logfile reading ([gh#votca/votca##1157])
* Sat Jul 20 2024 Christoph Junghans <junghans@votca.org>
- Drop 1032.patch, merged upstream
- Update to v2024.1
  - csg_reupdate: remove commented out dosteep ([gh#votca/votca#1103])
  - CI: drop gmx2023, add gmx2024 ([gh#votca/votca#1106])
  - new option to ignore segment types in KMC ([gh#votca/votca#1105])
  - fixed dftcoupling option path ([gh#votca/votca#1107])
  - cmake: fix MKL detection ([gh#votca/votca#1110])
  - cmake: handover GMX options transparently ([gh#votca/votca#1108])
  - CI: Switch Intel build to Ubuntu ([gh#votca/votca#1111])
  - CI: update GitHub actions ([gh#votca/votca#1112])
  - Fix Python print in hoomd tutorial ([gh#votca/votca#1118])
  - CI: fix warnings ([gh#votca/votca#1119], [gh#votca/votca#1122],
    [gh#votca/votca#1130], [gh#votca/votca#1138])
  - votca_help2doc: fix python warnings ([gh#votca/votca#1121])
  - Fix build with boost-1.85.0 ([gh#votca/votca#1123])
  - make some interpreters explicit  ([gh#votca/votca#1125],
    [gh#votca/votca#1129])
  - cmake: update hdf5 detection for cmake hdf5 ([gh#votca/votca#1126],
    [gh#votca/votca#1127])
  - scripts: use sed in posix way ([gh#votca/votca#1128])
  - add CI on FreeBSD ([gh#votca/votca#1124])
  - Fix Sphinx build ([gh#votca/votca#1131])
  - add CONTRIBUTING.md ([gh#votca/votca#1133])
  - csg_table fix ([gh#votca/votca#1134])
  - Added v2024 JOSS paper and link to older pubs ([gh#votca/votca#1132])
  - DFT and GW-BSE theory section in manual ([gh#votca/votca#1135])
  - add rate theory part to XTP manual section ([gh#votca/votca#1136])
  - adding transport model section to XTP manual ([gh#votca/votca#1137])
  - switching optimizer in XTP tutorial ([gh#votca/votca#1139],
    [gh#votca/votca#1140])
  - csg-tutorials: auto-detect gmx binary ([gh#votca/votca#1144])
  - add crest documentation ([gh#votca/votca#1145])
* Mon Jun  3 2024 Christoph Junghans <junghans@votca.org>
- Add upstream patch, 1032.patch, to fix build with newer boost
* Wed Jan 31 2024 Christoph Junghans <junghans@votca.org>
- Drop python3-espressomd testing dependency, revert once
  gh#espressomd/espresso#4856 is fixed.
* Thu Jan 25 2024 Christoph Junghans <junghans@votca.org>
- Dropped 1093.patch, merged upstream
  - fix links in README and doc ([gh#votca/votca#1091])
  - fix python shebang to python3 ([gh#votca/votca#1093])
  - Clean-up CI ([gh#votca/votca#1092], [gh#votca/votca#1095])
  - remove reference to old webpage ([gh#votca/votca#1094])
  - fix doc generation without pyxtp ([gh#votca/votca#1097])
  - Do not run gmx tests without libgromacs ([gh#votca/votca#1099])
  - KS-QMMM for single-particle states ([gh#votca/votca#1100])
  - Spin-orbitals from ORCA in QMMM ([gh#votca/votca#1101])
  - better unit test for DFT embedding ([gh#votca/votca#1102])
- Update to 2024
* Thu Nov 16 2023 Christoph Junghans <junghans@votca.org>
- Drop 1083.patch - merged upstream
- Add 1093.patch from upstream to fix python shebang
- Update to 2023
  - fix pyxtp option restart ([gh#votca/votca#1074])
  - fix Changelog check ([gh#votca/votca#1070])
  - add python bindings for xtp ([gh#votca/votca#1061])
  - replaced pointers in MD2QM mapping ([gh#votca/votca#1075])
  - fixed typo in esp2multipole option ([gh#votca/votca#1076])
  - update MKL detection to MKL config ([gh#votca/votca#1053])
  - remove geometry optimization ([gh#votca/votca#1077])
  - remove all references to old pdf manual ([gh#votca/votca#1081])
  - replaced deprecated boost::progress headers ([gh#votca/votca#1083])
  - drop intel classic builds from CI ([gh#votca/votca#1085])
  - disable some libint2 warning and CI clean up ([gh#votca/votca#1088])
  - fix population analysis for embedded DFT ([gh#votca/votca#1089])
  - fix pyxtp xtp-tutorials ([gh#votca/votca#1090])
  - add note on gmx build for install ([gh#votca/votca#1052])
  - fix typos in esp2multipole options ([gh#votca/votca#1054])
  - Used sharedable lock in xtp ([gh#votca/votca#1057])
  - Make votca tests compile without OpenMP ([gh#votca/votca#1065])
  - increase tolerance for diabatization test ([gh#votca/votca#1039],
    [gh#votca/votca#1043])
  - removed boost::filesystem  ([gh#votca/votca#1041])
  - clean up C++ defines ([gh#votca/votca#1044])
  - drop gmx-2022 builds from CI ([gh#votca/votca#1046])
  - update ccaching in CI ([gh#votca/votca#1048], [gh#votca/votca#1050])
  - add support for gmx-2023 api ([gh#votca/votca#1059])
  - updated formatting ([gh#votca/votca#1062])
  - remove stable branch workflow ([gh#votca/votca#1066])
  - Refactor changelog actions ([gh#votca/votca#1068])
  - fix CI build with icpx ([gh#votca/votca#1018])
  - implemented projection-based DFT embedding ([gh#votca/votca#964])
  - Added LMO energy output and cube file generation ([gh#votca/votca#970])
  - fix typos in csg-tutorials xml files ([gh#votca/votca#980])
  - unitary optimization for localization of orbitals ([gh#votca/votca#971])
  - separate option for density max convergence tolerance in qmmm
    ([gh#votca/votca#987])
  - Correct ECP charges added in Orca Molden reader ([gh#votca/votca#990])
  - Implemented truncated basis for embedded DFT ([gh#votca/votca#991])
  - Implemented ER diabatization for BSE ([gh#votca/votca#988])
  - update esp++ spce tutorial to py3 ([gh#votca/votca#997])
  - Truncated GW-in-DFT embedded in static/polar MM implemeted
    ([gh#votca/votca#1003])
  - reducing XTP tutorial size ([gh#votca/votca#1020], [gh#votca/votca#1025])
  - Clean up 3body Stillinger-Weber implement, docs and tutorial
    ([gh#votca/votca#1012])
  - fixed options handling in xtp_autogen_mapping ([gh#votca/votca#1024])
  - Major CMake refactor ([gh#votca/votca#950], [gh#votca/votca#1022])
  - Fix all doxygen warnings ([gh#votca/votca#1026])
  - basis and auxbasis are written to QMMM checkpoint file
    ([gh#votca/votca#1030])
  - iterations_max can now be zero ([gh#votca/votca#1033])
  - add an XML check to csg_inverse ([gh#votca/votca#1031])
  - fix propane/imc and add propane/imc-ibiintra to csg-tutorials
    ([gh#votca/votca#821])
* Mon Nov 13 2023 Christoph Junghans <junghans@votca.org>
- Add 1083.patch to fix build with boost-1.82
* Mon Jan  2 2023 Christoph Junghans <junghans@votca.org>
- don't use mpi gromacs on ix86
* Wed Dec 21 2022 Christoph Junghans <junghans@votca.org>
- Update to 2022.1
  - fix PROJECT_VERSION in subdirs ([gh#votca/votca#951])
  - make csg_resample and csg_stat spacing consistent
    ([gh#votca/votca#956])
  - fix build on FreeBSD ([gh#votca/votca#959])
  - update CI container names ([gh#votca/votca#961])
  - Fix gw quadrature scheme ([gh#votca/votca#967])
  - update install guide for spack ([gh#votca/votca#972],
    [gh#votca/votca#974])
  - drop gmx-2021 builds from CI ([gh#votca/votca#976])
  - update syntax for cmake 3.23 ([gh#votca/votca#978])
  - fix CI build on Ubuntu ([gh#votca/votca#981])
  - fix CI builds with icpx ([gh#votca/votca#984],
    [gh#votca/votca#1004])
  - fix CI builds with ESPResSo 4.2.0 ([gh#votca/votca#993])
  - fix localization issue ([gh#votca/votca#998],
    [gh#votca/votca#1000])
  - update github actions to new versions ([gh#votca/votca#1007],
    [gh#votca/votca#1013])
* Thu Dec 15 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable gromacs on 32-bit arm since it is missing
- Do not requires libint when xtp is disabled
* Wed Dec  7 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Adjust constraints to avoid rejecting too many workers, enable
  parallel builds with limit_build.
- Clean up specfile, remove obsolete __DATE__ mangling.
* Fri Jul 29 2022 Christoph Junghans <junghans@votca.org>
- only use python3-epressomd for testing on x86_64
* Sun Jan 16 2022 Christoph Junghans <junghans@votca.org>
- Update to 2022
  - fix some icpc warnings ([gh#votca/votca#934])
  - only check for pytest if testing is enabled
    ([gh#votca/votca#930])
  - exclude some builds from CI ([gh#votca/votca#940],
    [gh#votca/votca#942], [gh#votca/votca#944],
    [gh#votca/votca#945])
  - update interface documentation ([gh#votca/votca#939])
  - update install guide for binary packages
    ([gh#votca/votca#936])
  - fixed sigma plot options passing ([gh#votca/votca#943])
* Sun Dec 19 2021 Christoph Junghans <junghans@votca.org>
- Also obsoletes votca-csg-apps
* Thu Dec 16 2021 Christoph Junghans <junghans@votca.org>
- Update to 2022-rc.2
  - fix iqm merge orbitals command ([gh#votca/votca#907])
  - fix bug in basisset serialization that caused wrong Vxc values
    in GW ([gh#votca/votca#910])
  - update performance compilation info ([gh#votca/votca#911])
  - license for monorepo and all license files rst -> plain text
    ([gh#votca/votca#912], [gh#votca/votca#913])
  - use python3 in xtp-tutorials ([gh#votca/votca#917])
  - bump required boost version to 1.71 ([gh#votca/votca#915],
    [gh#votca/votca#916])
  - clean up NOTICE files ([gh#votca/votca#919])
  - rm PYTHON_INSTDIR from VOTCARC ([gh#votca/votca#924])
  - update citation in xtp README ([gh#votca/votca#925])
  - fix install permission of tutorials ([gh#votca/votca#926])-
* Mon Dec  6 2021 Christoph Junghans <junghans@votca.org>
- Merge votca-{tools,csg,xtp} into one package
